@@ -288,6 +288,18 @@ def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
     return execute(cmd)
 
 
+def executeTry(*parList, output=None, error=None):
+    _code, outputBytes, errorBytes = execute(*parList)
+    if type(output) == str:
+        output = output.encode()
+    if output and output not in outputBytes:
+        raise Exception(f"命令执行失败：{' '.join(parList)}")
+    if type(error) == str:
+        error = error.encode()
+    if error and error not in errorBytes:
+        raise Exception(f"命令执行失败：{' '.join(parList)}")
+
+
 def zipFile(toFile, fileFolderOrAry, rename=None):
     from zipfile import ZIP_DEFLATED, ZipFile
     makeFolder(os.path.dirname(toFile))
@@ -405,12 +417,13 @@ def strByTimestamp(timestamp=None, fmt=None):
     return time.strftime(fmt, ary)
 
 
-def hold(msg=None, exitValue=None):
+def hold(msg=None, *exitValueList):
     msg = msg or "测试暂停，输入exit可以退出"
-    exitValue = exitValue or "exit"
+    exitValueList = exitValueList or ["exit"]
     while True:
-        if getpass.getpass(f"{msg}：") == exitValue:
-            break
+        inputValue = getpass.getpass(f"{msg}：")
+        if inputValue in exitValueList:
+            return inputValue
 
 # ---- http
 
