@@ -1,4 +1,5 @@
 import sys
+import time
 
 import beniutils as b
 
@@ -29,11 +30,15 @@ def runMain(moduleName=None, **parDict):
     if isAllowRunMain:
         isAllowRunMain = False
         isError = False
-        lockFile = b.getPath(workspacePath, "pytool.lock")
+        lockFile = b.getPath(workspacePath, "tool.lock")
         b.checkLockFile(lockFile)
         isDebug = not not moduleName
         try:
-            b.initLogger()
+            logFolder = b.getPath(workspacePath, "log")
+            for logFile in sorted(b.getAllFileList(logFolder))[100:]:
+                b.remove(logFile)
+            logFile = b.getPath(logFolder, f"{time.strftime('%Y%m%d_%H%M%S')}.log")
+            b.initLogger(logFile=logFile)
             if not moduleName:
                 moduleName, parDict = initParDict()
             run(moduleName, **parDict)
